pub struct ChunkedStreamInfo {
pub stream: DynIoStream,
pub chunk_size: u64,
pub total_size: u64,
}Expand description
A stream that can be part of a larger file.
Fields
stream: DynIoStreamThe stream data.
chunk_size: u64The size of the current stream chunk, in bytes.
total_size: u64The total size of the file the stream was extracted from, in bytes.